@@ -11,33 +11,34 @@
  */
 
 /**
- * Retrieve the author of the current post.
+ * Retrieves the author of the current post.
  *
  * @since 1.5.0
  *
- * @global object $authordata The current author's DB object.
+ * @global WP_User $authordata The current author's data.
  *
  * @param string $deprecated Deprecated.
  * @return string|null The author's display name.
  */
-function get_the_author($deprecated = '') {
+function get_the_author( $deprecated = '' ) {
 	global $authordata;
 
-	if ( !empty( $deprecated ) )
+	if ( ! empty( $deprecated ) ) {
 		_deprecated_argument( __FUNCTION__, '2.1.0' );
+	}
 
 	/**
 	 * Filters the display name of the current post's author.
 	 *
 	 * @since 2.9.0
 	 *
-	 * @param string $authordata->display_name The author's display name.
+	 * @param string|null $display_name The author's display name.
 	 */
-	return apply_filters('the_author', is_object($authordata) ? $authordata->display_name : null);
+	return apply_filters( 'the_author', is_object( $authordata ) ? $authordata->display_name : null );
 }
 
 /**
- * Display the name of the author of the current post.
+ * Displays the name of the author of the current post.
  *
  * The behavior of this function is based off of old functionality predating
  * get_the_author(). This function is not deprecated, but is designed to echo
@@ -48,11 +49,12 @@ function get_the_author($deprecated = '') {
  * return it. However, backward compatibility has to be maintained.
  *
  * @since 0.71
- * @see get_the_author()
- * @link https://codex.wordpress.org/Template_Tags/the_author
  *
- * @param string $deprecated Deprecated.
- * @param string $deprecated_echo Deprecated. Use get_the_author(). Echo the string or return it.
+ * @see get_the_author()
+ * @link https://developer.wordpress.org/reference/functions/the_author/
+ *
+ * @param string $deprecated      Deprecated.
+ * @param bool   $deprecated_echo Deprecated. Use get_the_author(). Echo the string or return it.
  * @return string|null The author's display name, from get_the_author().
  */
 function the_author( $deprecated = '', $deprecated_echo = true ) {
@@ -61,9 +63,12 @@ function the_author( $deprecated = '', $deprecated_echo = true ) {
 	}
 
 	if ( true !== $deprecated_echo ) {
-		_deprecated_argument( __FUNCTION__, '1.5.0',
-			/* translators: %s: get_the_author() */
-			sprintf( __( 'Use %s instead if you do not want the value echoed.' ),
+		_deprecated_argument(
+			__FUNCTION__,
+			'1.5.0',
+			sprintf(
+				/* translators: %s: get_the_author() */
+				__( 'Use %s instead if you do not want the value echoed.' ),
 				'<code>get_the_author()</code>'
 			)
 		);
@@ -77,29 +82,31 @@ function the_author( $deprecated = '', $deprecated_echo = true ) {
 }
 
 /**
- * Retrieve the author who last edited the current post.
+ * Retrieves the author who last edited the current post.
  *
  * @since 2.8.0
  *
- * @return string|void The author's display name.
+ * @return string|void The author's display name, empty string if unknown.
  */
 function get_the_modified_author() {
-	if ( $last_id = get_post_meta( get_post()->ID, '_edit_last', true) ) {
-		$last_user = get_userdata($last_id);
+	$last_id = get_post_meta( get_post()->ID, '_edit_last', true );
+
+	if ( $last_id ) {
+		$last_user = get_userdata( $last_id );
 
 		/**
 		 * Filters the display name of the author who last edited the current post.
 		 *
 		 * @since 2.8.0
 		 *
-		 * @param string $last_user->display_name The author's display name.
+		 * @param string $display_name The author's display name, empty string if unknown.
 		 */
-		return apply_filters('the_modified_author', $last_user->display_name);
+		return apply_filters( 'the_modified_author', $last_user ? $last_user->display_name : '' );
 	}
 }
 
 /**
- * Display the name of the author who last edited the current post,
+ * Displays the name of the author who last edited the current post,
  * if the author's ID is available.
  *
  * @since 2.8.0
@@ -111,15 +118,45 @@ function the_modified_author() {
 }
 
 /**
- * Retrieve the requested data of the author of the current post.
- * @link https://codex.wordpress.org/Template_Tags/the_author_meta
+ * Retrieves the requested data of the author of the current post.
+ *
+ * Valid values for the `$field` parameter include:
+ *
+ * - admin_color
+ * - aim
+ * - comment_shortcuts
+ * - description
+ * - display_name
+ * - first_name
+ * - ID
+ * - jabber
+ * - last_name
+ * - nickname
+ * - plugins_last_view
+ * - plugins_per_page
+ * - rich_editing
+ * - syntax_highlighting
+ * - user_activation_key
+ * - user_description
+ * - user_email
+ * - user_firstname
+ * - user_lastname
+ * - user_level
+ * - user_login
+ * - user_nicename
+ * - user_pass
+ * - user_registered
+ * - user_status
+ * - user_url
+ * - yim
+ *
  * @since 2.8.0
  *
- * @global object $authordata The current author's DB object.
+ * @global WP_User $authordata The current author's data.
  *
- * @param string $field selects the field of the users record.
- * @param int $user_id Optional. User ID.
- * @return string The author's field from the current author's DB object.
+ * @param string    $field   Optional. The user field to retrieve. Default empty.
+ * @param int|false $user_id Optional. User ID.
+ * @return string The author's field from the current author's DB object, otherwise an empty string.
  */
 function get_the_author_meta( $field = '', $user_id = false ) {
 	$original_user_id = $user_id;
@@ -131,8 +168,9 @@ function get_the_author_meta( $field = '', $user_id = false ) {
 		$authordata = get_userdata( $user_id );
 	}
 
-	if ( in_array( $field, array( 'login', 'pass', 'nicename', 'email', 'url', 'registered', 'activation_key', 'status' ) ) )
+	if ( in_array( $field, array( 'login', 'pass', 'nicename', 'email', 'url', 'registered', 'activation_key', 'status' ), true ) ) {
 		$field = 'user_' . $field;
+	}
 
 	$value = isset( $authordata->$field ) ? $authordata->$field : '';
 
@@ -144,9 +182,9 @@ function get_the_author_meta( $field = '', $user_id = false ) {
 	 * @since 2.8.0
 	 * @since 4.3.0 The `$original_user_id` parameter was added.
 	 *
-	 * @param string   $value            The value of the metadata.
-	 * @param int      $user_id          The user ID for the value.
-	 * @param int|bool $original_user_id The original user ID, as passed to the function.
+	 * @param string    $value            The value of the metadata.
+	 * @param int       $user_id          The user ID for the value.
+	 * @param int|false $original_user_id The original user ID, as passed to the function.
 	 */
 	return apply_filters( "get_the_author_{$field}", $value, $user_id, $original_user_id );
 }
@@ -154,60 +192,80 @@ function get_the_author_meta( $field = '', $user_id = false ) {
 /**
  * Outputs the field from the user's DB object. Defaults to current post's author.
  *
- * @link https://codex.wordpress.org/Template_Tags/the_author_meta
- *
  * @since 2.8.0
  *
- * @param string $field selects the field of the users record.
- * @param int $user_id Optional. User ID.
+ * @param string    $field   Selects the field of the users record. See get_the_author_meta()
+ *                           for the list of possible fields.
+ * @param int|false $user_id Optional. User ID.
+ *
+ * @see get_the_author_meta()
  */
 function the_author_meta( $field = '', $user_id = false ) {
 	$author_meta = get_the_author_meta( $field, $user_id );
 
 	/**
-	 * The value of the requested user metadata.
+	 * Filters the value of the requested user metadata.
 	 *
 	 * The filter name is dynamic and depends on the $field parameter of the function.
 	 *
 	 * @since 2.8.0
 	 *
-	 * @param string $author_meta The value of the metadata.
-	 * @param int    $user_id     The user ID.
+	 * @param string    $author_meta The value of the metadata.
+	 * @param int|false $user_id     The user ID.
 	 */
 	echo apply_filters( "the_author_{$field}", $author_meta, $user_id );
 }
 
 /**
- * Retrieve either author's link or author's name.
+ * Retrieves either author's link or author's name.
  *
  * If the author has a home page set, return an HTML link, otherwise just return the
  * author's name.
  *
  * @since 3.0.0
  *
+ * @global WP_User $authordata The current author's data.
+ *
  * @return string|null An HTML link if the author's url exist in user meta,
  *                     else the result of get_the_author().
  */
 function get_the_author_link() {
-	if ( get_the_author_meta('url') ) {
-		return sprintf( '<a href="%1$s" title="%2$s" rel="author external">%3$s</a>',
-			esc_url( get_the_author_meta('url') ),
-			/* translators: %s: author's display name */
-			esc_attr( sprintf( __( 'Visit %s&#8217;s website' ), get_the_author() ) ),
-			get_the_author()
+	if ( get_the_author_meta( 'url' ) ) {
+		global $authordata;
+
+		$author_url          = get_the_author_meta( 'url' );
+		$author_display_name = get_the_author();
+
+		$link = sprintf(
+			'<a href="%1$s" title="%2$s" rel="author external">%3$s</a>',
+			esc_url( $author_url ),
+			/* translators: %s: Author's display name. */
+			esc_attr( sprintf( __( 'Visit %s&#8217;s website' ), $author_display_name ) ),
+			$author_display_name
 		);
+
+		/**
+		 * Filters the author URL link HTML.
+		 *
+		 * @since 6.0.0
+		 *
+		 * @param string  $link       The default rendered author HTML link.
+		 * @param string  $author_url Author's URL.
+		 * @param WP_User $authordata Author user data.
+		 */
+		return apply_filters( 'the_author_link', $link, $author_url, $authordata );
 	} else {
 		return get_the_author();
 	}
 }
 
 /**
- * Display either author's link or author's name.
+ * Displays either author's link or author's name.
  *
  * If the author has a home page set, echo an HTML link, otherwise just echo the
  * author's name.
  *
- * @link https://codex.wordpress.org/Template_Tags/the_author_link
+ * @link https://developer.wordpress.org/reference/functions/the_author_link/
  *
  * @since 2.1.0
  */
@@ -216,7 +274,7 @@ function the_author_link() {
 }
 
 /**
- * Retrieve the number of posts by the author of the current post.
+ * Retrieves the number of posts by the author of the current post.
  *
  * @since 1.5.0
  *
@@ -231,9 +289,9 @@ function get_the_author_posts() {
 }
 
 /**
- * Display the number of posts by the author of the current post.
+ * Displays the number of posts by the author of the current post.
  *
- * @link https://codex.wordpress.org/Template_Tags/the_author_posts
+ * @link https://developer.wordpress.org/reference/functions/the_author_posts/
  * @since 0.71
  */
 function the_author_posts() {
@@ -247,19 +305,20 @@ function the_author_posts() {
  *
  * @since 4.4.0
  *
- * @global object $authordata The current author's DB object.
+ * @global WP_User $authordata The current author's data.
  *
- * @return string An HTML link to the author page.
+ * @return string An HTML link to the author page, or an empty string if $authordata isn't defined.
  */
 function get_the_author_posts_link() {
 	global $authordata;
 	if ( ! is_object( $authordata ) ) {
-		return;
+		return '';
 	}
 
-	$link = sprintf( '<a href="%1$s" title="%2$s" rel="author">%3$s</a>',
+	$link = sprintf(
+		'<a href="%1$s" title="%2$s" rel="author">%3$s</a>',
 		esc_url( get_author_posts_url( $authordata->ID, $authordata->user_nicename ) ),
-		/* translators: %s: author's display name */
+		/* translators: %s: Author's display name. */
 		esc_attr( sprintf( __( 'Posts by %s' ), get_the_author() ) ),
 		get_the_author()
 	);
@@ -290,11 +349,11 @@ function the_author_posts_link( $deprecated = '' ) {
 }
 
 /**
- * Retrieve the URL to the author page for the user with the ID provided.
+ * Retrieves the URL to the author page for the user with the ID provided.
  *
  * @since 2.1.0
  *
- * @global WP_Rewrite $wp_rewrite
+ * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
  *
  * @param int    $author_id       Author ID.
  * @param string $author_nicename Optional. The author's nicename (slug). Default empty.
@@ -302,19 +361,21 @@ function the_author_posts_link( $deprecated = '' ) {
  */
 function get_author_posts_url( $author_id, $author_nicename = '' ) {
 	global $wp_rewrite;
-	$auth_ID = (int) $author_id;
-	$link = $wp_rewrite->get_author_permastruct();
 
-	if ( empty($link) ) {
+	$author_id = (int) $author_id;
+	$link      = $wp_rewrite->get_author_permastruct();
+
+	if ( empty( $link ) ) {
 		$file = home_url( '/' );
-		$link = $file . '?author=' . $auth_ID;
+		$link = $file . '?author=' . $author_id;
 	} else {
-		if ( '' == $author_nicename ) {
-			$user = get_userdata($author_id);
-			if ( !empty($user->user_nicename) )
+		if ( '' === $author_nicename ) {
+			$user = get_userdata( $author_id );
+			if ( ! empty( $user->user_nicename ) ) {
 				$author_nicename = $user->user_nicename;
+			}
 		}
-		$link = str_replace('%author%', $author_nicename, $link);
+		$link = str_replace( '%author%', $author_nicename, $link );
 		$link = home_url( user_trailingslashit( $link ) );
 	}
 
@@ -324,7 +385,7 @@ function get_author_posts_url( $author_id, $author_nicename = '' ) {
 	 * @since 2.1.0
 	 *
 	 * @param string $link            The URL to the author's page.
-	 * @param int    $author_id       The author's id.
+	 * @param int    $author_id       The author's ID.
 	 * @param string $author_nicename The author's nice name.
 	 */
 	$link = apply_filters( 'author_link', $link, $author_id, $author_nicename );
@@ -333,9 +394,9 @@ function get_author_posts_url( $author_id, $author_nicename = '' ) {
 }
 
 /**
- * List all the authors of the site, with several options available.
+ * Lists all the authors of the site, with several options available.
  *
- * @link https://codex.wordpress.org/Template_Tags/wp_list_authors
+ * @link https://developer.wordpress.org/reference/functions/wp_list_authors/
  *
  * @since 1.2.0
  *
@@ -350,56 +411,67 @@ function get_author_posts_url( $author_id, $author_nicename = '' ) {
  *     @type string       $order         Sorting direction for $orderby. Accepts 'ASC', 'DESC'. Default 'ASC'.
  *     @type int          $number        Maximum authors to return or display. Default empty (all authors).
  *     @type bool         $optioncount   Show the count in parenthesis next to the author's name. Default false.
- *     @type bool         $exclude_admin Whether to exclude the 'admin' account, if it exists. Default false.
+ *     @type bool         $exclude_admin Whether to exclude the 'admin' account, if it exists. Default true.
  *     @type bool         $show_fullname Whether to show the author's full name. Default false.
  *     @type bool         $hide_empty    Whether to hide any authors with no posts. Default true.
  *     @type string       $feed          If not empty, show a link to the author's feed and use this text as the alt
  *                                       parameter of the link. Default empty.
  *     @type string       $feed_image    If not empty, show a link to the author's feed and use this image URL as
  *                                       clickable anchor. Default empty.
- *     @type string       $feed_type     The feed type to link to, such as 'rss2'. Defaults to default feed type.
+ *     @type string       $feed_type     The feed type to link to. Possible values include 'rss2', 'atom'.
+ *                                       Default is the value of get_default_feed().
  *     @type bool         $echo          Whether to output the result or instead return it. Default true.
  *     @type string       $style         If 'list', each author is wrapped in an `<li>` element, otherwise the authors
  *                                       will be separated by commas.
  *     @type bool         $html          Whether to list the items in HTML form or plaintext. Default true.
- *     @type array|string $exclude       Array or comma/space-separated list of author IDs to exclude. Default empty.
- *     @type array|string $include       Array or comma/space-separated list of author IDs to include. Default empty.
+ *     @type int[]|string $exclude       Array or comma/space-separated list of author IDs to exclude. Default empty.
+ *     @type int[]|string $include       Array or comma/space-separated list of author IDs to include. Default empty.
  * }
- * @return string|void The output, if echo is set to false.
+ * @return void|string Void if 'echo' argument is true, list of authors if 'echo' is false.
  */
 function wp_list_authors( $args = '' ) {
 	global $wpdb;
 
 	$defaults = array(
-		'orderby' => 'name', 'order' => 'ASC', 'number' => '',
-		'optioncount' => false, 'exclude_admin' => true,
-		'show_fullname' => false, 'hide_empty' => true,
-		'feed' => '', 'feed_image' => '', 'feed_type' => '', 'echo' => true,
-		'style' => 'list', 'html' => true, 'exclude' => '', 'include' => ''
+		'orderby'       => 'name',
+		'order'         => 'ASC',
+		'number'        => '',
+		'optioncount'   => false,
+		'exclude_admin' => true,
+		'show_fullname' => false,
+		'hide_empty'    => true,
+		'feed'          => '',
+		'feed_image'    => '',
+		'feed_type'     => '',
+		'echo'          => true,
+		'style'         => 'list',
+		'html'          => true,
+		'exclude'       => '',
+		'include'       => '',
 	);
 
 	$args = wp_parse_args( $args, $defaults );
 
 	$return = '';
 
-	$query_args = wp_array_slice_assoc( $args, array( 'orderby', 'order', 'number', 'exclude', 'include' ) );
+	$query_args           = wp_array_slice_assoc( $args, array( 'orderby', 'order', 'number', 'exclude', 'include' ) );
 	$query_args['fields'] = 'ids';
-	$authors = get_users( $query_args );
+	$authors              = get_users( $query_args );
 
 	$author_count = array();
-	foreach ( (array) $wpdb->get_results( "SELECT DISTINCT post_author, COUNT(ID) AS count FROM $wpdb->posts WHERE " . get_private_posts_cap_sql( 'post' ) . " GROUP BY post_author" ) as $row ) {
-		$author_count[$row->post_author] = $row->count;
+	foreach ( (array) $wpdb->get_results( "SELECT DISTINCT post_author, COUNT(ID) AS count FROM $wpdb->posts WHERE " . get_private_posts_cap_sql( 'post' ) . ' GROUP BY post_author' ) as $row ) {
+		$author_count[ $row->post_author ] = $row->count;
 	}
 	foreach ( $authors as $author_id ) {
-		$author = get_userdata( $author_id );
+		$posts = isset( $author_count[ $author_id ] ) ? $author_count[ $author_id ] : 0;
 
-		if ( $args['exclude_admin'] && 'admin' == $author->display_name ) {
+		if ( ! $posts && $args['hide_empty'] ) {
 			continue;
 		}
 
-		$posts = isset( $author_count[$author->ID] ) ? $author_count[$author->ID] : 0;
+		$author = get_userdata( $author_id );
 
-		if ( ! $posts && $args['hide_empty'] ) {
+		if ( $args['exclude_admin'] && 'admin' === $author->display_name ) {
 			continue;
 		}
 
@@ -415,13 +487,14 @@ function wp_list_authors( $args = '' ) {
 			continue; // No need to go further to process HTML.
 		}
 
-		if ( 'list' == $args['style'] ) {
+		if ( 'list' === $args['style'] ) {
 			$return .= '<li>';
 		}
 
-		$link = sprintf( '<a href="%1$s" title="%2$s">%3$s</a>',
-			get_author_posts_url( $author->ID, $author->user_nicename ),
-			/* translators: %s: author's display name */
+		$link = sprintf(
+			'<a href="%1$s" title="%2$s">%3$s</a>',
+			esc_url( get_author_posts_url( $author->ID, $author->user_nicename ) ),
+			/* translators: %s: Author's display name. */
 			esc_attr( sprintf( __( 'Posts by %s' ), $author->display_name ) ),
 			$name
 		);
@@ -436,7 +509,7 @@ function wp_list_authors( $args = '' ) {
 
 			$alt = '';
 			if ( ! empty( $args['feed'] ) ) {
-				$alt = ' alt="' . esc_attr( $args['feed'] ) . '"';
+				$alt  = ' alt="' . esc_attr( $args['feed'] ) . '"';
 				$name = $args['feed'];
 			}
 
@@ -456,26 +529,31 @@ function wp_list_authors( $args = '' ) {
 		}
 
 		if ( $args['optioncount'] ) {
-			$link .= ' ('. $posts . ')';
+			$link .= ' (' . $posts . ')';
 		}
 
 		$return .= $link;
-		$return .= ( 'list' == $args['style'] ) ? '</li>' : ', ';
+		$return .= ( 'list' === $args['style'] ) ? '</li>' : ', ';
 	}
 
 	$return = rtrim( $return, ', ' );
 
-	if ( ! $args['echo'] ) {
+	if ( $args['echo'] ) {
+		echo $return;
+	} else {
 		return $return;
 	}
-	echo $return;
 }
 
 /**
- * Does this site have more than one author
+ * Determines whether this site has more than one author.
  *
  * Checks to see if more than one author has published posts.
  *
+ * For more information on this and similar theme functions, check out
+ * the {@link https://developer.wordpress.org/themes/basics/conditional-tags/
+ * Conditional Tags} article in the Theme Developer Handbook.
+ *
  * @since 3.2.0
  *
  * @global wpdb $wpdb WordPress database abstraction object.
@@ -485,8 +563,9 @@ function wp_list_authors( $args = '' ) {
 function is_multi_author() {
 	global $wpdb;
 
-	if ( false === ( $is_multi_author = get_transient( 'is_multi_author' ) ) ) {
-		$rows = (array) $wpdb->get_col("SELECT DISTINCT post_author FROM $wpdb->posts WHERE post_type = 'post' AND post_status = 'publish' LIMIT 2");
+	$is_multi_author = get_transient( 'is_multi_author' );
+	if ( false === $is_multi_author ) {
+		$rows            = (array) $wpdb->get_col( "SELECT DISTINCT post_author FROM $wpdb->posts WHERE post_type = 'post' AND post_status = 'publish' LIMIT 2" );
 		$is_multi_author = 1 < count( $rows ) ? 1 : 0;
 		set_transient( 'is_multi_author', $is_multi_author );
 	}
@@ -507,6 +586,6 @@ function is_multi_author() {
  * @since 3.2.0
  * @access private
  */
-function __clear_multi_author_cache() {
+function __clear_multi_author_cache() { // phpcs:ignore WordPress.NamingConventions.ValidFunctionName.FunctionDoubleUnderscore,PHPCompatibility.FunctionNameRestrictions.ReservedFunctionNames.FunctionDoubleUnderscore
 	delete_transient( 'is_multi_author' );
 }
