@@ -68,7 +68,7 @@
 				// Used when the interval is reset.
 				originalInterval: 0,
 
-				// Used to limit the number of AJAX requests.
+				// Used to limit the number of Ajax requests.
 				minimalInterval: 0,
 
 				// Used together with tempInterval.
@@ -146,7 +146,7 @@
 				}
 
 				/*
-				 * Used to limit the number of AJAX requests. Overrides all other intervals
+				 * Used to limit the number of Ajax requests. Overrides all other intervals
 				 * if they are shorter. Needed for some hosts that cannot handle frequent requests
 				 * and the user may exceed the allocated server CPU time, etc. The minimal interval
 				 * can be up to 600 seconds, however setting it to longer than 120 seconds
@@ -155,7 +155,7 @@
 				 */
 				if ( options.minimalInterval ) {
 					options.minimalInterval = parseInt( options.minimalInterval, 10 );
-					settings.minimalInterval = options.minimalInterval > 0 && options.minimalInterval <= 600 ? options.minimalInterval * 1000 : 0;
+					settings.minimalInterval = options.minimalInterval > 0 && options.minimalInterval <= 600 ? options.minimalInterval : 0;
 				}
 
 				if ( settings.minimalInterval && settings.mainInterval < settings.minimalInterval ) {
@@ -176,6 +176,9 @@
 			// Convert to milliseconds.
 			settings.mainInterval = settings.mainInterval * 1000;
 			settings.originalInterval = settings.mainInterval;
+			if ( settings.minimalInterval ) {
+				settings.minimalInterval = settings.minimalInterval * 1000;
+			}
 
 			/*
 			 * Switch the interval to 120 seconds by using the Page Visibility API.
@@ -234,7 +237,7 @@
 			window.setInterval( checkUserActivity, 30000 );
 
 			// Start one tick after DOM ready.
-			$document.ready( function() {
+			$( function() {
 				settings.lastTick = time();
 				scheduleNextTick();
 			});
