@@ -12,13 +12,13 @@
  * @package WordPress
  */
 
-require_once( dirname( __FILE__ ) . '/wp-load.php' );
+require_once __DIR__ . '/wp-load.php';
 
 header( 'Content-Type: text/xml; charset=' . get_option( 'blog_charset' ), true );
 $link_cat = '';
 if ( ! empty( $_GET['link_cat'] ) ) {
 	$link_cat = $_GET['link_cat'];
-	if ( ! in_array( $link_cat, array( 'all', '0' ) ) ) {
+	if ( ! in_array( $link_cat, array( 'all', '0' ), true ) ) {
 		$link_cat = absint( (string) urldecode( $link_cat ) );
 	}
 }
@@ -29,7 +29,7 @@ echo '<?xml version="1.0"?' . ">\n";
 	<head>
 		<title>
 		<?php
-			/* translators: %s: site name */
+			/* translators: %s: Site title. */
 			printf( __( 'Links for %s' ), esc_attr( get_bloginfo( 'name', 'display' ) ) );
 		?>
 		</title>
@@ -80,9 +80,9 @@ foreach ( (array) $cats as $cat ) :
 		 */
 		$title = apply_filters( 'link_title', $bookmark->link_name );
 		?>
-<outline text="<?php echo esc_attr( $title ); ?>" type="link" xmlUrl="<?php echo esc_attr( $bookmark->link_rss ); ?>" htmlUrl="<?php echo esc_attr( $bookmark->link_url ); ?>" updated="
+<outline text="<?php echo esc_attr( $title ); ?>" type="link" xmlUrl="<?php echo esc_url( $bookmark->link_rss ); ?>" htmlUrl="<?php echo esc_url( $bookmark->link_url ); ?>" updated="
 							<?php
-							if ( '0000-00-00 00:00:00' != $bookmark->link_updated ) {
+							if ( '0000-00-00 00:00:00' !== $bookmark->link_updated ) {
 								echo $bookmark->link_updated;}
 							?>
 " />
